@@ -1,4 +1,4 @@
-VERSION="1.3.3"
+VERSION="1.3.4"
 
 #set -x
 
@@ -58,6 +58,10 @@ is_relative() {
   echo "$1" | grep -v '^/' >/dev/null
 }
 
+is_nested() {
+  echo "$1" | sed "s|$DEST_DIR/||" | grep '/' >/dev/null
+}
+
 version() {
   cat << EOV
 $1 (rcm) $VERSION
@@ -167,6 +171,14 @@ decode() {
   echo "$file" | tr "$DELIMITER" " "
 }
 
+append_variable() {
+  if [ -z "$1" ]; then
+    echo "$2"
+  else
+    echo "$1 $2"
+  fi
+}
+
 : ${RCRC:=$HOME/.rcrc}
 
 if [ -r "$RCRC" ]; then
